==> dashboard-view-1.8.2-sources.jar: hudson/plugins/view/dashboard/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.view.dashboard;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * failed
     * 
     */
    public static String Dashboard_Failed() {
        return holder.format("Dashboard.Failed");
    }

    /**
     * failed
     * 
     */
    public static Localizable _Dashboard_Failed() {
        return new Localizable(holder, "Dashboard.Failed");
    }

    /**
     * Unstable Jobs
     * 
     */
    public static String Dashboard_UnstableJobs() {
        return holder.format("Dashboard.UnstableJobs");
    }

    /**
     * Unstable Jobs
     * 
     */
    public static Localizable _Dashboard_UnstableJobs() {
        return new Localizable(holder, "Dashboard.UnstableJobs");
    }

    /**
     * Dashboard
     * 
     */
    public static String Dashboard_DisplayName() {
        return holder.format("Dashboard.DisplayName");
    }

    /**
     * Dashboard
     * 
     */
    public static Localizable _Dashboard_DisplayName() {
        return new Localizable(holder, "Dashboard.DisplayName");
    }

    /**
     * No data available
     * 
     */
    public static String Dashboard_NoDataAvailable() {
        return holder.format("Dashboard.NoDataAvailable");
    }

    /**
     * No data available
     * 
     */
    public static Localizable _Dashboard_NoDataAvailable() {
        return new Localizable(holder, "Dashboard.NoDataAvailable");
    }

    /**
     * All recent builds failed
     * 
     */
    public static String Dashboard_AllRecentBuildsFailed() {
        return holder.format("Dashboard.AllRecentBuildsFailed");
    }

    /**
     * All recent builds failed
     * 
     */
    public static Localizable _Dashboard_AllRecentBuildsFailed() {
        return new Localizable(holder, "Dashboard.AllRecentBuildsFailed");
    }

    /**
     * Test Statistics Chart
     * 
     */
    public static String Dashboard_TestStatisticsChart() {
        return holder.format("Dashboard.TestStatisticsChart");
    }

    /**
     * Test Statistics Chart
     * 
     */
    public static Localizable _Dashboard_TestStatisticsChart() {
        return new Localizable(holder, "Dashboard.TestStatisticsChart");
    }

    /**
     * Latest builds
     * 
     */
    public static String Dashboard_LatestBuilds() {
        return holder.format("Dashboard.LatestBuilds");
    }

    /**
     * Latest builds
     * 
     */
    public static Localizable _Dashboard_LatestBuilds() {
        return new Localizable(holder, "Dashboard.LatestBuilds");
    }

    /**
     * Unknown status
     * 
     */
    public static String Dashboard_UnknownStatus() {
        return holder.format("Dashboard.UnknownStatus");
    }

    /**
     * Unknown status
     * 
     */
    public static Localizable _Dashboard_UnknownStatus() {
        return new Localizable(holder, "Dashboard.UnknownStatus");
    }

    /**
     * Hudson jobs list
     * 
     */
    public static String Dashboard_HudsonJobsList() {
        return holder.format("Dashboard.HudsonJobsList");
    }

    /**
     * Hudson jobs list
     * 
     */
    public static Localizable _Dashboard_HudsonJobsList() {
        return new Localizable(holder, "Dashboard.HudsonJobsList");
    }

    /**
     * total
     * 
     */
    public static String Dashboard_Total() {
        return holder.format("Dashboard.Total");
    }

    /**
     * total
     * 
     */
    public static Localizable _Dashboard_Total() {
        return new Localizable(holder, "Dashboard.Total");
    }

    /**
     * {0}-{1}% of recent builds failed
     * 
     */
    public static String Dashboard_RecentBuildsFailed(Object arg1, Object arg2) {
        return holder.format("Dashboard.RecentBuildsFailed", arg1, arg2);
    }

    /**
     * {0}-{1}% of recent builds failed
     * 
     */
    public static Localizable _Dashboard_RecentBuildsFailed(Object arg1, Object arg2) {
        return new Localizable(holder, "Dashboard.RecentBuildsFailed", arg1, arg2);
    }

    /**
     * Test Statistics Grid
     * 
     */
    public static String Dashboard_TestStatisticsGrid() {
        return holder.format("Dashboard.TestStatisticsGrid");
    }

    /**
     * Test Statistics Grid
     * 
     */
    public static Localizable _Dashboard_TestStatisticsGrid() {
        return new Localizable(holder, "Dashboard.TestStatisticsGrid");
    }

    /**
     * Build statistics
     * 
     */
    public static String Dashboard_BuildStatistics() {
        return holder.format("Dashboard.BuildStatistics");
    }

    /**
     * Build statistics
     * 
     */
    public static Localizable _Dashboard_BuildStatistics() {
        return new Localizable(holder, "Dashboard.BuildStatistics");
    }

    /**
     * Jobs Grid
     * 
     */
    public static String Dashboard_JobsGrid() {
        return holder.format("Dashboard.JobsGrid");
    }

    /**
     * Jobs Grid
     * 
     */
    public static Localizable _Dashboard_JobsGrid() {
        return new Localizable(holder, "Dashboard.JobsGrid");
    }

    /**
     * Test Trend Chart
     * 
     */
    public static String Dashboard_TestTrendChart() {
        return holder.format("Dashboard.TestTrendChart");
    }

    /**
     * Test Trend Chart
     * 
     */
    public static Localizable _Dashboard_TestTrendChart() {
        return new Localizable(holder, "Dashboard.TestTrendChart");
    }

    /**
     * Job statistics
     * 
     */
    public static String Dashboard_JobStatistics() {
        return holder.format("Dashboard.JobStatistics");
    }

    /**
     * Job statistics
     * 
     */
    public static Localizable _Dashboard_JobStatistics() {
        return new Localizable(holder, "Dashboard.JobStatistics");
    }

    /**
     * count
     * 
     */
    public static String Dashboard_Count() {
        return holder.format("Dashboard.Count");
    }

    /**
     * count
     * 
     */
    public static Localizable _Dashboard_Count() {
        return new Localizable(holder, "Dashboard.Count");
    }

    /**
     * date
     * 
     */
    public static String Dashboard_Date() {
        return holder.format("Dashboard.Date");
    }

    /**
     * date
     * 
     */
    public static Localizable _Dashboard_Date() {
        return new Localizable(holder, "Dashboard.Date");
    }

    /**
     * No recent builds failed
     * 
     */
    public static String Dashboard_NoRecentBuildsFailed() {
        return holder.format("Dashboard.NoRecentBuildsFailed");
    }

    /**
     * No recent builds failed
     * 
     */
    public static Localizable _Dashboard_NoRecentBuildsFailed() {
        return new Localizable(holder, "Dashboard.NoRecentBuildsFailed");
    }

    /**
     * success
     * 
     */
    public static String Dashboard_Success() {
        return holder.format("Dashboard.Success");
    }

    /**
     * success
     * 
     */
    public static Localizable _Dashboard_Success() {
        return new Localizable(holder, "Dashboard.Success");
    }

    /**
     * skipped
     * 
     */
    public static String Dashboard_Skipped() {
        return holder.format("Dashboard.Skipped");
    }

    /**
     * skipped
     * 
     */
    public static Localizable _Dashboard_Skipped() {
        return new Localizable(holder, "Dashboard.Skipped");
    }

}

==> dashboard-view-2.9.2-sources.jar: hudson/plugins/view/dashboard/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.view.dashboard;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * failed
     * 
     */
    public static String Dashboard_Failed() {
        return holder.format("Dashboard.Failed");
    }

    /**
     * failed
     * 
     */
    public static Localizable _Dashboard_Failed() {
        return new Localizable(holder, "Dashboard.Failed");
    }

    /**
     * Unstable Jobs
     * 
     */
    public static String Dashboard_UnstableJobs() {
        return holder.format("Dashboard.UnstableJobs");
    }

    /**
     * Unstable Jobs
     * 
     */
    public static Localizable _Dashboard_UnstableJobs() {
        return new Localizable(holder, "Dashboard.UnstableJobs");
    }

    /**
     * Dashboard
     * 
     */
    public static String Dashboard_DisplayName() {
        return holder.format("Dashboard.DisplayName");
    }

    /**
     * Dashboard
     * 
     */
    public static Localizable _Dashboard_DisplayName() {
        return new Localizable(holder, "Dashboard.DisplayName");
    }

    /**
     * No data available
     * 
     */
    public static String Dashboard_NoDataAvailable() {
        return holder.format("Dashboard.NoDataAvailable");
    }

    /**
     * No data available
     * 
     */
    public static Localizable _Dashboard_NoDataAvailable() {
        return new Localizable(holder, "Dashboard.NoDataAvailable");
    }

    /**
     * Image
     * 
     */
    public static String Dashboard_Image() {
        return holder.format("Dashboard.Image");
    }

    /**
     * Image
     * 
     */
    public static Localizable _Dashboard_Image() {
        return new Localizable(holder, "Dashboard.Image");
    }

    /**
     * All recent builds failed
     * 
     */
    public static String Dashboard_AllRecentBuildsFailed() {
        return holder.format("Dashboard.AllRecentBuildsFailed");
    }

    /**
     * All recent builds failed
     * 
     */
    public static Localizable _Dashboard_AllRecentBuildsFailed() {
        return new Localizable(holder, "Dashboard.AllRecentBuildsFailed");
    }

    /**
     * Iframe Portlet
     * 
     */
    public static String Dashboard_IframePortlet() {
        return holder.format("Dashboard.IframePortlet");
    }

    /**
     * Iframe Portlet
     * 
     */
    public static Localizable _Dashboard_IframePortlet() {
        return new Localizable(holder, "Dashboard.IframePortlet");
    }

    /**
     * Jenkins jobs list
     * 
     */
    public static String Dashboard_JenkinsJobsList() {
        return holder.format("Dashboard.JenkinsJobsList");
    }

    /**
     * Jenkins jobs list
     * 
     */
    public static Localizable _Dashboard_JenkinsJobsList() {
        return new Localizable(holder, "Dashboard.JenkinsJobsList");
    }

    /**
     * Test Statistics Chart
     * 
     */
    public static String Dashboard_TestStatisticsChart() {
        return holder.format("Dashboard.TestStatisticsChart");
    }

    /**
     * Test Statistics Chart
     * 
     */
    public static Localizable _Dashboard_TestStatisticsChart() {
        return new Localizable(holder, "Dashboard.TestStatisticsChart");
    }

    /**
     * Latest builds
     * 
     */
    public static String Dashboard_LatestBuilds() {
        return holder.format("Dashboard.LatestBuilds");
    }

    /**
     * Latest builds
     * 
     */
    public static Localizable _Dashboard_LatestBuilds() {
        return new Localizable(holder, "Dashboard.LatestBuilds");
    }

    /**
     * Unknown status
     * 
     */
    public static String Dashboard_UnknownStatus() {
        return holder.format("Dashboard.UnknownStatus");
    }

    /**
     * Unknown status
     * 
     */
    public static Localizable _Dashboard_UnknownStatus() {
        return new Localizable(holder, "Dashboard.UnknownStatus");
    }

    /**
     * total
     * 
     */
    public static String Dashboard_Total() {
        return holder.format("Dashboard.Total");
    }

    /**
     * total
     * 
     */
    public static Localizable _Dashboard_Total() {
        return new Localizable(holder, "Dashboard.Total");
    }

    /**
     * {0}-{1}% of recent builds failed
     * 
     */
    public static String Dashboard_RecentBuildsFailed(Object arg1, Object arg2) {
        return holder.format("Dashboard.RecentBuildsFailed", arg1, arg2);
    }

    /**
     * {0}-{1}% of recent builds failed
     * 
     */
    public static Localizable _Dashboard_RecentBuildsFailed(Object arg1, Object arg2) {
        return new Localizable(holder, "Dashboard.RecentBuildsFailed", arg1, arg2);
    }

    /**
     * Test Statistics Grid
     * 
     */
    public static String Dashboard_TestStatisticsGrid() {
        return holder.format("Dashboard.TestStatisticsGrid");
    }

    /**
     * Test Statistics Grid
     * 
     */
    public static Localizable _Dashboard_TestStatisticsGrid() {
        return new Localizable(holder, "Dashboard.TestStatisticsGrid");
    }

    /**
     * Build statistics
     * 
     */
    public static String Dashboard_BuildStatistics() {
        return holder.format("Dashboard.BuildStatistics");
    }

    /**
     * Build statistics
     * 
     */
    public static Localizable _Dashboard_BuildStatistics() {
        return new Localizable(holder, "Dashboard.BuildStatistics");
    }

    /**
     * Jobs Grid
     * 
     */
    public static String Dashboard_JobsGrid() {
        return holder.format("Dashboard.JobsGrid");
    }

    /**
     * Jobs Grid
     * 
     */
    public static Localizable _Dashboard_JobsGrid() {
        return new Localizable(holder, "Dashboard.JobsGrid");
    }

    /**
     * Test Trend Chart
     * 
     */
    public static String Dashboard_TestTrendChart() {
        return holder.format("Dashboard.TestTrendChart");
    }

    /**
     * Test Trend Chart
     * 
     */
    public static Localizable _Dashboard_TestTrendChart() {
        return new Localizable(holder, "Dashboard.TestTrendChart");
    }

    /**
     * Job statistics
     * 
     */
    public static String Dashboard_JobStatistics() {
        return holder.format("Dashboard.JobStatistics");
    }

    /**
     * Job statistics
     * 
     */
    public static Localizable _Dashboard_JobStatistics() {
        return new Localizable(holder, "Dashboard.JobStatistics");
    }

    /**
     * Slaves statistics
     * 
     */
    public static String Dashboard_SlavesStatistics() {
        return holder.format("Dashboard.SlavesStatistics");
    }

    /**
     * Slaves statistics
     * 
     */
    public static Localizable _Dashboard_SlavesStatistics() {
        return new Localizable(holder, "Dashboard.SlavesStatistics");
    }

    /**
     * count
     * 
     */
    public static String Dashboard_Count() {
        return holder.format("Dashboard.Count");
    }

    /**
     * count
     * 
     */
    public static Localizable _Dashboard_Count() {
        return new Localizable(holder, "Dashboard.Count");
    }

    /**
     * date
     * 
     */
    public static String Dashboard_Date() {
        return holder.format("Dashboard.Date");
    }

    /**
     * date
     * 
     */
    public static Localizable _Dashboard_Date() {
        return new Localizable(holder, "Dashboard.Date");
    }

    /**
     * No recent builds failed
     * 
     */
    public static String Dashboard_NoRecentBuildsFailed() {
        return holder.format("Dashboard.NoRecentBuildsFailed");
    }

    /**
     * No recent builds failed
     * 
     */
    public static Localizable _Dashboard_NoRecentBuildsFailed() {
        return new Localizable(holder, "Dashboard.NoRecentBuildsFailed");
    }

    /**
     * success
     * 
     */
    public static String Dashboard_Success() {
        return holder.format("Dashboard.Success");
    }

    /**
     * success
     * 
     */
    public static Localizable _Dashboard_Success() {
        return new Localizable(holder, "Dashboard.Success");
    }

    /**
     * skipped
     * 
     */
    public static String Dashboard_Skipped() {
        return holder.format("Dashboard.Skipped");
    }

    /**
     * skipped
     * 
     */
    public static Localizable _Dashboard_Skipped() {
        return new Localizable(holder, "Dashboard.Skipped");
    }

}
